from distutils.core import setup

setup(
       name        = 'netest',
       version     = '1.0.1',
       py_modules  = ['netest'],
#      author      = 'gong',
#       author_email = 'fishgolang@gmail.com',
#      url         = 'http://www.baidu.com',
#       description = 'a test modules',
     )
